HoprBlockchainConnector

Struct HoprBlockchainConnector 

pub struct HoprBlockchainConnector<C, B, P, R> {
Show 15 fields payload_generator: P, chain_key: ChainKeypair, client: Arc<C>, graph: Arc<RwLock<DiGraphMap<HoprKeyIdent, ChannelId, RandomState>>>, backend: Arc<B>, connection_handle: Option<AbortHandle>, sequencer: TransactionSequencer<C, R>, events: (Sender<ChainEvent>, InactiveReceiver<ChainEvent>), cfg: BlockchainConnectorConfig, mapper: HoprKeyMapper<B>, chain_to_packet: Cache<Address, Option<OffchainPublicKey>, RandomState>, packet_to_chain: Cache<OffchainPublicKey, Option<Address>, RandomState>, channel_by_id: Cache<ChannelId, Option<ChannelEntry>, RandomState>, channel_by_parties: Cache<ChannelParties, Option<ChannelEntry>, RandomState>, values: Cache<u32, ParsedChainInfo>,
}
A connector acting as middleware between the HOPR APIs (see the [hopr_api] crate) and the Blokli Client API (see the [blokli_client] crate).

The connector object cannot be cloned and shall be used inside an Arc if cloning is needed.

Fields

payload_generator: Pchain_key: ChainKeypairclient: Arc<C>graph: Arc<RwLock<DiGraphMap<HoprKeyIdent, ChannelId, RandomState>>>backend: Arc<B>connection_handle: Option<AbortHandle>sequencer: TransactionSequencer<C, R>events: (Sender<ChainEvent>, InactiveReceiver<ChainEvent>)cfg: BlockchainConnectorConfigmapper: HoprKeyMapper<B>chain_to_packet: Cache<Address, Option<OffchainPublicKey>, RandomState>packet_to_chain: Cache<OffchainPublicKey, Option<Address>, RandomState>channel_by_id: Cache<ChannelId, Option<ChannelEntry>, RandomState>channel_by_parties: Cache<ChannelParties, Option<ChannelEntry>, RandomState>values: Cache<u32, ParsedChainInfo>

Implementations

Source

impl<B, C, P, R> HoprBlockchainConnector<C, B, P, R>
where B: Backend + Send + Sync + 'static,

pub(crate) fn build_account_stream( &self, selector: AccountSelector, ) -> Result<impl Stream<Item = AccountEntry> + Send + 'static, ConnectorError>

Source

impl<B, C, P, R> HoprBlockchainConnector<C, B, P, R>
where B: Backend + Send + Sync + 'static,

pub(crate) fn build_channel_stream( &self, selector: ChannelSelector, ) -> Result<impl Stream<Item = ChannelEntry> + Send + 'static, ConnectorError>

Source

impl<B, C, P> HoprBlockchainConnector<C, B, P, P::TxRequest>
where B: Backend + Send + Sync + 'static, C: BlokliTransactionClient + BlokliQueryClient + Send + Sync + 'static, P: PayloadGenerator + Send + Sync + 'static, P::TxRequest: Send + Sync + 'static,

Source

impl<B, C, P, R> HoprBlockchainConnector<C, R, B, P>
where C: BlokliQueryClient + Send + Sync + 'static,

pub(crate) async fn query_cached_chain_info( &self, ) -> Result<ParsedChainInfo, ConnectorError>

Queries chain info from cache, fetching from Blokli on cold start.

The cache has no TTL - it’s kept fresh by the Blokli subscription handler which updates it whenever ticket parameters change. This prevents the cascading timeout issue where cache expiration during packet processing would trigger blocking Blokli queries.

Source

impl<B, C, P> HoprBlockchainConnector<C, B, P, P::TxRequest>
where B: Backend + Send + Sync + 'static, C: BlokliSubscriptionClient + BlokliQueryClient + BlokliTransactionClient + Send + Sync + 'static, P: PayloadGenerator + Send + Sync + 'static, P::TxRequest: Send + Sync + 'static,

pub fn new( chain_key: ChainKeypair, cfg: BlockchainConnectorConfig, client: C, backend: B, payload_generator: P, ) -> Self

Creates a new instance.

async fn do_connect( &self, timeout: Duration, ) -> Result<AbortHandle, ConnectorError>

pub async fn connect(&mut self) -> Result<(), ConnectorError>

Connects to the chain using the underlying client, syncs all on-chain data, and subscribes for all future updates.

If the connection does not finish within BlockchainConnectorConfig::connection_timeout the ConnectorError::ConnectionTimeout error is returned.

Most of the operations with the Connector will fail if it is not connected first.

There are some notable exceptions that DO NOT require a prior call to connect:

If you wish to only call operations from the above Chain APIs, consider constructing the HoprBlockchainReader instead.

pub fn client(&self) -> &C

Returns the reference to the underlying client.

pub fn is_connected(&self) -> bool

Checks if the connector is connected to the chain.

Source

impl<B, C, P> HoprBlockchainConnector<C, B, P, P::TxRequest>

async fn send_tx<'a>( &'a self, tx_req: P::TxRequest, custom_tx_multiplier: Option<u32>, ) -> Result<impl Future<Output = Result<ChainReceipt, ConnectorError>> + Send + 'a, ConnectorError>

Source

impl<B, C, P, R> HoprBlockchainConnector<C, R, B, P>

pub(crate) fn check_connection_state(&self) -> Result<(), ConnectorError>

pub fn invalidate_caches(&self)

Invalidates all cached on-chain data.

Source

impl<B, C, P, R> HoprBlockchainConnector<C, B, P, R>
where B: Backend + Send + Sync + 'static, C: Send + Sync, P: Send + Sync, R: Send + Sync,

pub fn as_path_resolver(&self) -> ChainPathResolver<'_, Self>

Returns a [PathAddressResolver] using this connector.